==> vlab-0.0.9-py3-none-any.whl: vlab/utils/download.py <==
import os.path
import re

import gdown

ENV_XDG_CACHE_HOME = "XDG_CACHE_HOME"
DEFAULT_CACHE_DIR = "~/.cache"


def parse_file_id(url):
    pattern = r"/file/d/(.*?)/view"
    match = re.search(pattern, url)
    if match:
        file_id = match.groups()[0]
        return file_id
    else:
        raise ValueError("Invalid URL")


CHECKPOINT_FILE_IDS = {
    "raft-small": parse_file_id("https://drive.google.com/file/d/16ge0XYXekBkMvjb6WYbJuykFE94IWVJm/view?usp=sharing"),
    "raft-sintel": parse_file_id("https://drive.google.com/file/d/1fubTHIa_b2C8HqfbPtKXwoRd9QsYxRL6/view?usp=sharing"),
    "raft-kitti": parse_file_id("https://drive.google.com/file/d/1gBpZIYOZaK1D9rANDuTos6jsn3uLwQoL/view?usp=sharing"),
    "raft-things": parse_file_id("https://drive.google.com/file/d/1MqDajR89k-xLV0HIrmJ0k-n8ZpG6_suM/view?usp=sharing"),
    "raft-chairs": parse_file_id("https://drive.google.com/file/d/1JW7qCizcf4A5csiM1H6z5wZ6kAWDHIKH/view?usp=sharing"),
}


def get_vlab_home():
    vlab_home = os.path.expanduser(os.path.join(os.getenv(ENV_XDG_CACHE_HOME, DEFAULT_CACHE_DIR), "vlab"))
    return vlab_home


def get_checkpoint_dir():
    checkpoint_dir = os.path.join(get_vlab_home(), "checkpoints")
    return checkpoint_dir


def download_checkpoint(ckpt_name, verbose=True):
    if ckpt_name not in CHECKPOINT_FILE_IDS:
        raise ValueError("Unknown checkpoint name: {}".format(ckpt_name))

    file_id = CHECKPOINT_FILE_IDS[ckpt_name]
    url = f"https://drive.google.com/uc?id={file_id}"

    ckpt_dir = get_checkpoint_dir()
    ckpt_path = os.path.join(ckpt_dir, f"{ckpt_name}.pth")

    if os.path.exists(ckpt_path):
        if verbose:
            print(f"Checkpoint already exists: {ckpt_path}")
        return ckpt_path

    os.makedirs(ckpt_dir, exist_ok=True)
    gdown.download(url, output=ckpt_path, quiet=not verbose)

    return ckpt_path


def clean_state_dict(state_dict):
    """Remove the "module." prefix from the state_dict keys."""
    new_state_dict = {}
    for k, v in state_dict.items():
        new_state_dict[k.replace("module.", "")] = v
    return new_state_dict


if __name__ == "__main__":
    download_checkpoint("raft-small")

==> vlab-0.0.10-py3-none-any.whl: vlab/utils/download.py <==
import os.path
import re
from urllib.request import urlretrieve

import gdown

ENV_XDG_CACHE_HOME = "XDG_CACHE_HOME"
DEFAULT_CACHE_DIR = "~/.cache"


def parse_file_id(url):
    pattern = r"/file/d/(.*?)/view"
    match = re.search(pattern, url)
    if match:
        file_id = match.groups()[0]
        return file_id
    else:
        raise ValueError("Invalid URL")


CHECKPOINT_FILE_IDS = {
    "raft-small": parse_file_id("https://drive.google.com/file/d/16ge0XYXekBkMvjb6WYbJuykFE94IWVJm/view?usp=sharing"),
    "raft-sintel": parse_file_id("https://drive.google.com/file/d/1fubTHIa_b2C8HqfbPtKXwoRd9QsYxRL6/view?usp=sharing"),
    "raft-kitti": parse_file_id("https://drive.google.com/file/d/1gBpZIYOZaK1D9rANDuTos6jsn3uLwQoL/view?usp=sharing"),
    "raft-things": parse_file_id("https://drive.google.com/file/d/1MqDajR89k-xLV0HIrmJ0k-n8ZpG6_suM/view?usp=sharing"),
    "raft-chairs": parse_file_id("https://drive.google.com/file/d/1JW7qCizcf4A5csiM1H6z5wZ6kAWDHIKH/view?usp=sharing"),
}


def get_vlab_home():
    vlab_home = os.path.expanduser(os.path.join(os.getenv(ENV_XDG_CACHE_HOME, DEFAULT_CACHE_DIR), "vlab"))
    return vlab_home


def get_subdir(subdir_name="checkpoints"):
    subdir = os.path.join(get_vlab_home(), subdir_name)
    return subdir


def download_checkpoint(ckpt_name, verbose=True):
    if ckpt_name not in CHECKPOINT_FILE_IDS:
        raise ValueError("Unknown checkpoint name: {}".format(ckpt_name))

    file_id = CHECKPOINT_FILE_IDS[ckpt_name]
    url = f"https://drive.google.com/uc?id={file_id}"

    ckpt_dir = get_subdir("checkpoints")
    ckpt_path = os.path.join(ckpt_dir, f"{ckpt_name}.pth")

    if os.path.exists(ckpt_path):
        if verbose:
            print(f"Checkpoint already exists: {ckpt_path}")
        return ckpt_path

    os.makedirs(ckpt_dir, exist_ok=True)
    gdown.download(url, output=ckpt_path, quiet=not verbose)

    return ckpt_path


def download_file(url, filename, verbose=True):
    down_dir = get_subdir("downloads")
    output_path = os.path.join(down_dir, filename)

    if os.path.exists(output_path):
        if verbose:
            print(f"File already exists: {output_path}")
        return output_path

    os.makedirs(down_dir, exist_ok=True)
    if "drive.google.com" in url:
        gdown.download(url, output=output_path, fuzzy=True, quiet=not verbose)
    else:
        if verbose:
            print(f"Downloading {url} to {output_path}")
        urlretrieve(url, output_path)

    return output_path


def clean_state_dict(state_dict):
    """Remove the "module." prefix from the state_dict keys."""
    new_state_dict = {}
    for k, v in state_dict.items():
        new_state_dict[k.replace("module.", "")] = v
    return new_state_dict


if __name__ == "__main__":
    output_path = download_file(
        "https://dl.fbaipublicfiles.com/dino/dino_deitsmall8_pretrain/dino_deitsmall8_pretrain.pth",
        "dino_deitsmall8_pretrain.pth",
    )
    print(output_path)
